Coverage report

File | statements | missing | excluded | coverage
--- | --- | --- | --- | ---
src/ramses_cli/__init__.py | 6 | 2 | 0 | 67%
src/ramses_cli/client.py | 307 | 171 | 4 | 44%
src/ramses_cli/debug.py | 12 | 7 | 0 | 42%
src/ramses_cli/discovery.py | 185 | 132 | 2 | 29%
src/ramses_rf/__init__.py | 14 | 0 | 2 | 100%
src/ramses_rf/binding_fsm.py | 339 | 154 | 6 | 55%
src/ramses_rf/const.py | 21 | 0 | 2 | 100%
src/ramses_rf/database.py | 220 | 185 | 3 | 16%
src/ramses_rf/device/__init__.py | 45 | 29 | 3 | 36%
src/ramses_rf/device/base.py | 224 | 133 | 8 | 41%
src/ramses_rf/device/heat.py | 657 | 369 | 5 | 44%
src/ramses_rf/device/hvac.py | 349 | 197 | 0 | 44%
src/ramses_rf/dispatcher.py | 114 | 91 | 2 | 20%
src/ramses_rf/entity_base.py | 593 | 483 | 17 | 19%
src/ramses_rf/exceptions.py | 25 | 0 | 0 | 100%
src/ramses_rf/gateway.py | 220 | 168 | 4 | 24%
src/ramses_rf/helpers.py | 56 | 45 | 0 | 20%
src/ramses_rf/schemas.py | 106 | 37 | 4 | 65%
src/ramses_rf/system/__init__.py | 6 | 0 | 0 | 100%
src/ramses_rf/system/faultlog.py | 158 | 109 | 2 | 31%
src/ramses_rf/system/heat.py | 513 | 351 | 5 | 32%
src/ramses_rf/system/schedule.py | 237 | 157 | 2 | 34%
src/ramses_rf/system/zones.py | 410 | 244 | 7 | 40%
src/ramses_rf/version.py | 2 | 0 | 0 | 100%
src/ramses_tx/__init__.py | 25 | 4 | 2 | 84%
src/ramses_tx/address.py | 104 | 58 | 2 | 44%
src/ramses_tx/command.py | 636 | 482 | 4 | 24%
src/ramses_tx/const.py | 512 | 25 | 0 | 95%
src/ramses_tx/exceptions.py | 29 | 9 | 0 | 69%
src/ramses_tx/fingerprints.py | 8 | 2 | 0 | 75%
src/ramses_tx/frame.py | 216 | 175 | 3 | 19%
src/ramses_tx/gateway.py | 130 | 95 | 7 | 27%
src/ramses_tx/helpers.py | 373 | 286 | 3 | 23%
src/ramses_tx/logger.py | 141 | 78 | 0 | 45%
src/ramses_tx/message.py | 159 | 109 | 4 | 31%
src/ramses_tx/opentherm.py | 249 | 93 | 0 | 63%
src/ramses_tx/packet.py | 115 | 77 | 0 | 33%
src/ramses_tx/parsers.py | 942 | 812 | 3 | 14%
src/ramses_tx/protocol.py | 322 | 250 | 6 | 22%
src/ramses_tx/protocol_fsm.py | 305 | 245 | 5 | 20%
src/ramses_tx/ramses.py | 53 | 0 | 0 | 100%
src/ramses_tx/schemas.py | 132 | 31 | 0 | 77%
src/ramses_tx/transport.py | 793 | 613 | 5 | 23%
src/ramses_tx/typed_dicts.py | 309 | 0 | 0 | 100%
src/ramses_tx/typing.py | 57 | 12 | 66 | 79%
src/ramses_tx/version.py | 2 | 0 | 0 | 100%
tests/tests/__init__.py | 0 | 0 | 0 | 100%
tests/tests/helpers.py | 89 | 89 | 0 | 0%
tests/tests/test_api_faultlog.py | 102 | 102 | 0 | 0%
tests/tests/test_api_schedule.py | 41 | 41 | 0 | 0%
tests/tests/test_apis_binding.py | 39 | 39 | 0 | 0%
tests/tests/test_apis_common.py | 57 | 57 | 0 | 0%
tests/tests/test_apis_heat.py | 130 | 130 | 0 | 0%
tests/tests/test_apis_hvac.py | 54 | 54 | 0 | 0%
tests/tests/test_devices.py | 35 | 35 | 0 | 0%
tests/tests/test_eavesdrop_dev_class.py | 48 | 48 | 0 | 0%
tests/tests/test_eavesdrop_schema.py | 42 | 42 | 0 | 0%
tests/tests/test_helpers.py | 63 | 63 | 0 | 0%
tests/tests/test_parser_helpers.py | 63 | 63 | 0 | 0%
tests/tests/test_parsers.py | 65 | 65 | 0 | 0%
tests/tests/test_ramses_schema.py | 33 | 33 | 0 | 0%
tests/tests/test_schema_bits.py | 22 | 22 | 0 | 0%
tests/tests/test_schemas.py | 28 | 28 | 0 | 0%
tests/tests/test_systems.py | 70 | 70 | 0 | 0%
tests/tests/test_vol_schemas.py | 124 | 124 | 0 | 0%
tests/tests_cli/test_cli_utility.py | 38 | 3 | 0 | 92%
tests/tests_rf/__init__.py | 0 | 0 | 0 | 100%
tests/tests_rf/conftest.py | 142 | 142 | 0 | 0%
tests/tests_rf/device/__init__.py | 0 | 0 | 0 | 100%
tests/tests_rf/device/test_hvac_ventilator.py | 240 | 240 | 0 | 0%
tests/tests_rf/test_api_faultlog.py | 66 | 66 | 0 | 0%
tests/tests_rf/test_api_schedule.py | 46 | 46 | 0 | 0%
tests/tests_rf/test_binding_fsm.py | 151 | 151 | 0 | 0%
tests/tests_rf/test_create_stack.py | 75 | 75 | 0 | 0%
tests/tests_rf/test_database.py | 84 | 84 | 0 | 0%
tests/tests_rf/test_dispatcher.py | 50 | 50 | 0 | 0%
tests/tests_rf/test_entity_base.py | 84 | 84 | 0 | 0%
tests/tests_rf/test_hgi_behaviors.py | 71 | 71 | 0 | 0%
tests/tests_rf/test_protocol_fsm.py | 199 | 199 | 0 | 0%
tests/tests_rf/test_use_regex.py | 70 | 70 | 0 | 0%
tests/tests_rf/test_virt_network.py | 103 | 103 | 0 | 0%
tests/tests_rf/virtual_rf/__init__.py | 47 | 47 | 0 | 0%
tests/tests_rf/virtual_rf/const.py | 21 | 21 | 0 | 0%
tests/tests_rf/virtual_rf/helpers.py | 13 | 13 | 0 | 0%
tests/tests_rf/virtual_rf/virtual_rf.py | 215 | 215 | 0 | 0%
tests/tests_tx/__init__.py | 0 | 0 | 0 | 100%
tests/tests_tx/test_command.py | 63 | 63 | 0 | 0%
Total | 13314 | 9368 | 188 | 30%

No items found using the specified filter.